@@ -5,12 +5,23 @@ from PIL import Image
 from requests.models import Response
 import json
 
-def get_upload_image_mock_request(image_path):
+def get_upload_image_preprocess_input(image_path: str, name: str):
+    """Return a mock input for preprocess that simulates the input from proxy while it was invoked as follows:
+    curl -F "filename=test.png" -F "name=@test.png" PROXY_API_URL
+
+    Keyword arguments:
+    image_path -- the path to the file
+    name -- the name in input.files
+
+    Usage:
+        input = get_upload_image_preprocess_input('test.png', 'image')
+        image = input.files["image"]
+    """
     with open(image_path, "rb") as img:
         image_content = img.read()
         file_name = os.path.basename(image_path)
         data = (b"--boundary\r\n")
-        data += (b'Content-Disposition: form-data; name="image"; filename="') + file_name.encode() + (b'"\r\n')
+        data += (b'Content-Disposition: form-data; name="') + name + (b'"; filename="') + file_name.encode() + (b'"\r\n')
         image_info = Image.open(image_path)
         data += (b"Content-Type: ") + image_info.get_format_mimetype().encode() + (b"\r\n")
         data += (b"\r\n")
@@ -26,7 +37,12 @@ def get_upload_image_mock_request(image_path):
 
         return request
 
-def get_inference_mock_response(inference_result):
+def get_postprocess_input(inference_result):
+    """Return a mock input for postprocess that inference_result simulates the result form model inferencing.
+
+    Keyword arguments:
+    inference_result -- the result that simulates the result form model inferencing
+    """
     response = Response()
     response.code = "ok"
     response.status_code = 200
